@@ -48,6 +48,7 @@ int ipkg_init_options_array(const ipkg_conf_t *conf, ipkg_option_t **options)
 	  { "force_defaults", IPKG_OPT_TYPE_BOOL, &conf->force_defaults },
 	  { "force_depends", IPKG_OPT_TYPE_BOOL, &conf->force_depends },
 	  { "force_overwrite", IPKG_OPT_TYPE_BOOL, &conf->force_overwrite },
+	  { "force_downgrade", IPKG_OPT_TYPE_BOOL, &conf->force_downgrade },
 	  { "force_reinstall", IPKG_OPT_TYPE_BOOL, &conf->force_reinstall },
 	  { "force_space", IPKG_OPT_TYPE_BOOL, &conf->force_space },
 	  { "ftp_proxy", IPKG_OPT_TYPE_STRING, &conf->ftp_proxy },
@@ -136,6 +137,7 @@ int ipkg_conf_init(ipkg_conf_t *conf, const args_t *args)
      conf->force_depends = 0;
      conf->force_defaults = 0;
      conf->force_overwrite = 0;
+     conf->force_downgrade = 0;
      conf->force_reinstall = 0;
      conf->force_space = 0;
      conf->force_removal_of_essential_packages = 0;
@@ -231,6 +233,9 @@ int ipkg_conf_init(ipkg_conf_t *conf, const args_t *args)
      if (args->force_overwrite) {
 	  conf->force_overwrite = 1;
      }
+     if (args->force_downgrade) {
+	  conf->force_downgrade = 1;
+     }
      if (args->force_reinstall) {
 	  conf->force_reinstall = 1;
      }
